@@ -1,5 +1,5 @@
 /* test_ntlm.c --- Test module for libntlm.
- * Copyright (C) 2004 Frediano Ziglio
+ * Copyright (C) 2004, 2005 Frediano Ziglio
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
@@ -27,7 +27,6 @@ static int
 md4file (const char *name, unsigned char *hash)
 {
   FILE *f;
-  MD4_CTX context;
   char line[1024];
   int res = 0;
 
@@ -35,18 +34,7 @@ md4file (const char *name, unsigned char *hash)
   if (!f)
     return 1;
 
-  MD4Init (&context);
-  while (fgets (line, sizeof (line), f))
-    {
-      char *p = strstr (line, "\r\n");
-      if (p && p[2] == 0)
-	strcpy (p, "\n");
-      MD4Update (&context, line, strlen (line));
-    }
-  MD4Final (&context, hash);
-
-  if (ferror (f))
-    res = 1;
+  res = md4_stream (f, hash);
 
   fclose (f);
 
@@ -125,7 +113,7 @@ fillChallenge (tSmbNtlmAuthChallenge * challenge, const char *domain)
 {
   int index = 0;
 
-  Bzero (challenge, sizeof (*challenge));
+  memset (challenge, 0, sizeof (*challenge));
   memcpy (challenge->ident, "NTLMSSP\0\0\0", 8);
   challenge->msgType = intelEndian32 (2);
   fillUnicode (&challenge->uDomain, challenge->buffer,
@@ -148,6 +136,11 @@ main ()
   if (!f)
     return 1;
 
+  printf ("ntlm.h %s libntlm %s\n", NTLM_VERSION, ntlm_check_version (NULL));
+
+  if (!ntlm_check_version (NTLM_VERSION))
+    return 1;
+
   /* do some test then dump */
   buildSmbNtlmAuthRequest (&request, "myuser", "mydomain");
   dumpSmbNtlmAuthRequest (f, &request);
